pub enum TailState {
Clean,
TruncatedAt {
segment_base: Lsn,
offset: u64,
},
}Expand description
State of the active segment’s tail after recovery (6).
Variants
Clean
The tail ended cleanly (sentinel / end of records); no truncation.
TruncatedAt
A torn tail was detected, truncated, and durably zeroed at this offset of the active segment (8.2.1).